#
# Barpanel "QuickTerminal" plugin
#
# Copyright (C) 2005 - 2006, Federico Pelloni <federico.pelloni@gmail.com>
# Copyright (C) 2008 Job and Esther Technologies Ltd
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#

name = "QuickTerminal"
description = "An always-ready terminal on Barpanel"

import barpanel, gtk, vte

class TerminalWindow(barpanel.PopupWindow):
    def __init__(self, panel):
        barpanel.PopupWindow.__init__(self, panel, 3, gtk.WINDOW_TOPLEVEL)
        self.set_type_hint(gtk.gdk.WINDOW_TYPE_HINT_NORMAL)
        self.set_header("QuickTerminal", "Your terminal always ready.")
        terminal = vte.Terminal()
        self.connect("focus-in-event", lambda w,e: terminal.grab_focus())
        terminal.set_emulation("xterm")
        terminal.set_font_from_string("monospace 12")
        terminal.set_allow_bold(True)
        terminal.set_scrollback_lines(100)
        terminal.show()
        box = gtk.HBox(False, 2)
        self.add(box)
        box.add(terminal)
        box.show()
        scrollbar = gtk.VScrollbar()
        scrollbar.show()
    	scrollbar.set_adjustment(terminal.get_adjustment())
        box.add(scrollbar)
        terminal.fork_command()
        terminal.connect("child-exited", self.__cb_exited)
    
    def __cb_exited(self, terminal):
        terminal.fork_command()
        self.toggle()

class Plugin(barpanel.Plugin):
    def __init__(self, panel, settings):
        barpanel.Plugin.__init__(self, panel, settings)
        self._twindow = TerminalWindow(panel)
        btn = gtk.ToggleButton()
        btn.set_name("EdgeButton")
        btn.connect("toggled", self._twindow.toggle)
        btn.set_relief(gtk.RELIEF_NONE)
        self.add(btn)
        box = gtk.HBox(False, 2)
        btn.add(box)

        aicon = "gnome-terminal"
        albl = "QuickTerminal"
        if settings.has_key('icon') and settings['icon']!=None:
            aicon = settings['icon']
        if settings.has_key('label') and settings['label']!=None:
            albl = settings['label']

        if len(aicon)>0:
            img = self.panel.get_image_from_icon_name(aicon)
            box.add(img)
        if len(albl)>0:
            lbl = gtk.Label(albl)
            panel.update_font(self, lbl)
            box.add(lbl)

        self.show_all()
