#
# Barpanel "SearchBox" plugin
# 
# Copyright (C) 2005 - 2006, Federico Pelloni <federico.pelloni@gmail.com>
# Copyright (C) 2008 Job and Esther Technologies Ltd
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Library General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
#

name = "SearchBox"
description = """Provide a smart box to search on the internet."""

import barpanel, gtk, gobject, os, pango

class SearchWindow(barpanel.BarpanelMenuWindow):
    def __init__(self, panel, plugin):
        barpanel.BarpanelMenuWindow.__init__(self, "Web search", "Search the World Wide Web - type your search below", \
                                                 panel.get_image_from_icon_name("web-browser", 24), panel, 3, \
                                                 gtk.WINDOW_TOPLEVEL)
        self.plugin = plugin

        self.set_type_hint(gtk.gdk.WINDOW_TYPE_HINT_NORMAL)

        box = gtk.HBox(False, 2)
        box.set_border_width(5)
        self.append(box)
        self.entry = gtk.Entry()
        self.entry.x_done = False
        self.entry.set_name("TextBox")
        self.entry.set_width_chars(15)
        self.entry.connect("button-press-event", self.manage_click)
        self.entry.connect("activate", self.go)
        box.pack_start(self.entry, True)
        btn = gtk.Button()
        btn.set_name("EdgeButton")
        btn.connect("clicked", self.onClicked)
        btn.set_label("Search")
        btn.set_relief(gtk.RELIEF_NONE)
        box.pack_end(btn, False)
        box.show_all()

    def onClicked(self, btn):
        self.executeSearch()

    def go(self, entry):
        self.executeSearch()

    def executeSearch(self):
        url = "'" + self.plugin.engineurl % self.entry.get_text() + "'"
        cmd = self.plugin.browser % url
        self.plugin.logDEBUG(_("Launching \"%s\"") % (cmd))
        os.spawnl(os.P_NOWAIT, "/bin/sh", "/bin/sh", "-c", cmd)
        self.entry.x_done = True
        self.entry.set_text("")
        self.toggle()
    
    def manage_click(self, entry, event):
        self.fixFocus()
    
    def fixFocus(self):
        self.entry.grab_focus()
        self.panel.set_focus(self.entry)
        if self.entry.x_done:
            self.entry.set_text("")
            self.entry.x_done = False

    def toggle(self, widget = 0):
        barpanel.PopupWindow.toggle(self, widget)
        self.fixFocus()

class Plugin(barpanel.Plugin):
    def __init__(self, panel, settings):
        barpanel.Plugin.__init__(self, panel, settings)

        self.browser = "firefox %s"
        self.engineurl = "http://www.igelle.net/search/?cx=partner-pub-2304692790833715:z1f2z9-6a6s&cof=FORID:10&q=%s&sa=Search"
        if settings.has_key('browser'):
            self.browser = settings['browser']
            if self.browser.find("%s") < 0:
                self.browser += " %s"
        if settings.has_key('engineurl'):
            self.engineurl = settings['engineurl']
        self.swindow = SearchWindow(panel, self)
        self.logDEBUG("Browser set to '%s'" % (self.browser))

        btn = gtk.ToggleButton()
        btn.set_name("EdgeButton")
        btn.connect("toggled", self.swindow.toggle)
        btn.connect("enter-notify-event", self.swindow.toggleConditional)
        btn.set_relief(gtk.RELIEF_NONE)
        if settings.has_key('desc') and settings['desc'] != None and len(settings['desc'])>0:
            barpanel.tooltips.set_tip(btn, settings['desc'])
        else:
            barpanel.tooltips.set_tip(btn, "Search the world wide web")
        self.add(btn)

        box = gtk.HBox(False, 2)
        btn.add(box)

        aicon = "web-browser"
        albl = "Web Search"
        if settings.has_key('icon') and settings['icon']!=None:
            aicon = settings['icon']
        if settings.has_key('label') and settings['label']!=None:
            albl = settings['label']

        if len(aicon)>0:
            img = self.panel.get_image_from_icon_name(aicon)
            box.add(img)
        if len(albl)>0:
            lbl = gtk.Label(_(albl))
            panel.update_font(self, lbl)
            box.add(lbl)

        self.show_all()
